@@ -23,6 +23,31 @@
   */
 #include "rsync.h"
 
+
+void log_open(void)
+{
+	static int initialised;
+	int options = LOG_PID;
+
+	if (initialised) return;
+	initialised = 1;
+
+#ifdef LOG_NDELAY
+	options |= LOG_NDELAY;
+#endif
+
+#ifdef LOG_DAEMON
+	openlog("rsyncd", options, lp_syslog_facility());
+#else
+	openlog("rsyncd", options);
+#endif
+
+#ifndef LOG_NDELAY
+	syslog(LOG_INFO,"rsyncd started\n");
+#endif
+}
+		
+
 /* this is the rsync debugging function. Call it with FINFO or FERROR */
 void rprintf(int fd, const char *format, ...)
 {
@@ -33,13 +58,7 @@ void rprintf(int fd, const char *format, ...)
 	extern int am_daemon;
 
 	va_start(ap, format);
-
-#if HAVE_VSNPRINTF
-	len = vsnprintf(buf, sizeof(buf)-1, format, ap);
-#else
-	vsprintf(buf, format, ap);
-	len = strlen(buf);
-#endif
+	len = vslprintf(buf, sizeof(buf)-1, format, ap);
 	va_end(ap);
 
 	if (len < 0) exit_cleanup(1);
@@ -49,19 +68,10 @@ void rprintf(int fd, const char *format, ...)
 	buf[len] = 0;
 
 	if (am_daemon) {
-		static int initialised;
 		int priority = LOG_INFO;
 		if (fd == FERROR) priority = LOG_WARNING;
 
-		if (!initialised) {
-			initialised = 1;
-#ifdef LOG_DAEMON
-			openlog("rsyncd", LOG_PID, lp_syslog_facility());
-#else
-			openlog("rsyncd", LOG_PID);
-#endif
-		}
-		
+		log_open();
 		syslog(priority, "%s", buf);
 		return;
 	}
