@@ -242,11 +242,15 @@ static int do_recv(int f_in,int f_out,struct file_list *flist,char *local_name)
   
 
 	if ((pid=do_fork()) == 0) {
+		close(recv_pipe[0]);
+		if (f_in != f_out) close(f_out);
 		recv_files(f_in,flist,local_name,recv_pipe[1]);
 		if (am_daemon) report(-1);
 		exit_cleanup(0);
 	}
 
+	close(recv_pipe[1]);
+	if (f_in != f_out) close(f_in);
 	generate_files(f_out,flist,local_name,recv_pipe[0]);
 
 	waitpid(pid, &status, 0);
@@ -501,6 +505,11 @@ int main(int argc,char *argv[])
 		return daemon_main();
 	}
 
+	if (argc < 1) {
+		usage(FERROR);
+		exit(1);
+	}
+
 	if (dry_run)
 		verbose = MAX(verbose,1);
 
